class AccountController < ApplicationController

  # If you want "remember me" functionality, add the this before_filter uncommended to Application Controller
  #before_filter :login_from_cookie

  before_filter :login_required, :except => [ :login, :logout ]
  #before_filter :login_from_cookie
  private :authorized?
 
  # protect some methods for only admins
  def authorized?
    if ['signup', 'destroy'].include?(action_name)
       return false unless current_user.is_admin?
    end
    return true
  end


  layout 'admin'

  def index
    # if a db is empty add admin
    redirect_to(:action => 'signup') unless User.count > 0
    # if is admin render 'users' partial
    @user_pages, @users = paginate :users, :per_page => 25, :order => "login" if current_user.is_admin?
  end

  def login
    return unless request.post?
    self.current_user = User.authenticate(params[:login], params[:password])
    if current_user
      if params[:remember_me] == "1"
        self.current_user.remember_me
        cookies[:auth_token] = { :value => self.current_user.remember_token , :expires => self.current_user.remember_token_expires_at }
      end
      redirect_back_or_default(:controller => '/account', :action => 'index')
      flash[:notice] = "Logged in successfully"
    end
  end

  def signup
    @user = User.new(params[:user])
    return unless request.post?
    @user.save!
    self.current_user = @user
    redirect_back_or_default(:controller => '/account', :action => 'index')
    flash[:notice] = "Thanks for signing up!"
  rescue ActiveRecord::RecordInvalid
    render :action => 'signup'
  end
  
  def logout
    self.current_user.forget_me if logged_in?
    cookies.delete :auth_token
    reset_session
    flash[:notice] = "You have been logged out."
    redirect_back_or_default(:controller => '/account', :action => 'index')
  end










end
