class Admin::CategoriesController < ApplicationController
  
  before_filter :login_required
  private :authorized?
  
  def authorized?
    current_user.login == "admin"
  end

  layout 'admin'
  
  observer :audit_observer


  verify :method => :post, :except => [ :index, :list, :new, :edit ],
         :redirect_to => { :action => :list }


  def index
    list
    render :action => 'list'
  end

  def list
    # TODO real implement the pagination...
    # - drag'n'drop between the pages and redirect to the correct page
    @category_pages, @categories = paginate :categories, :per_page => 25, :order => "position"
  end

  def sort
    @categories = Category.find(:all)
    @categories.each do |c|
      c.position = params['sorted-list'].index(c.id.to_s) + 1
      c.save
    end
    render :nothing => true
  end

  def new
    @category = Category.new
  end

  def create
    @category = Category.new(params[:category])
    if @category.save
      flash[:notice] = 'Category was successfully created.'
      redirect_to :action => 'list'
    else
      render :action => 'new'
    end
  end

  def edit
    @category = Category.find(params[:id])
  end

  def update
    @category = Category.find(params[:id])
    if @category.update_attributes(params[:category])
      flash[:notice] = 'Category was successfully updated.'
      redirect_to :action => 'list'
    else
      render :action => 'edit'
    end
  end
  
  def disable
    params[:category].each { | c_id, content |
      c = Category.find(c_id)
      c.update_attribute(:disabled,content[:disabled]) if c.disabled.to_s != content[:disabled]
    }
    redirect_to :action => 'list', :page => params[:page]
  end

  def destroy
    Category.find(params[:id]).destroy
    redirect_to :action => 'list'
  end
end
