class Admin::ItemsController < ApplicationController

  before_filter :login_required
  private :authorized?
  
  def authorized?
    current_user.login == "admin"
  end

  layout 'admin'

  observer :audit_observer


  verify :method => :post, :except => [ :index, :list, :new, :edit ],
         :redirect_to => { :action => :list }

  def index
    flash[:notice] = 'You must select the category'
    redirect_to( :controller => "categories")
  end

  def list

    # TODO real implement the pagination...
    # - drag'n'drop between the pages and redirect to the correct page

    if params[:id]
#      if Category.find(params[:id]).disabled
#        flash[:notice] = 'This category is disabled!'
#        redirect_to( :controller => "categories")
#      end
      session[:cat_id] = params[:id]
    else
      session[:cat_id] = nil
      index
    end
    
#    @item_pages = Paginator.new self, @items.count, 1, @params['page']
#    @items = Category.find(session[:cat_id]).items
    @item_pages, @items = paginate :items, :conditions => ["category_id  = ?", session[:cat_id]], :order => "position", :per_page => 10
    
  end
  
  def sort
    @items = Category.find(session[:cat_id]).items
#    @item = Item.find(:all, :conditions => ["category_id = ?", session[:cat_id]])
    @items.each do |i|
      i.position = params['sorted-list'].index(i.id.to_s) + 1
      i.save
    end
    render :nothing => true
  end

  def new
    @item = Item.new # serve per i valori di default
  end

  def create
    @item = Item.new(params[:item])
    @item.category_id = session[:cat_id] # this is more fast of @item.category = Category.find(session[:cat_id])

    if @item.save
      flash[:notice] = 'Item was successfully created.'
      redirect_to :action => 'list', :id => session[:cat_id]
    else
      render :action => 'new'
    end
  end

  def edit
    @item = Item.find(params[:id])
  end

  def update
    @item = Item.find(params[:id])
    if @item.update_attributes(params[:item])
      flash[:notice] = 'Item was successfully updated.'
      redirect_to :action => 'list', :id => session[:cat_id]
    else
      render :action => 'edit'
    end
  end
  
  def disable
    params[:item].each { | i_id, content |
      i = Item.find(i_id)
      i.update_attribute(:disabled,content[:disabled]) if i.disabled.to_s != content[:disabled]
    }
    redirect_to :action => 'list', :id => session[:cat_id]
  end

  def destroy
    Item.find(params[:id]).destroy
    redirect_to :action => 'list', :id => session[:cat_id]
  end
end
