class OrdineController < ApplicationController

  observer :audit_observer

  layout :determine_layout
  
  def determine_layout
    if request.xhr?
      false
    else
      "admin"
    end
  end


  def index
    @all = Category.find(:all, :conditions => "disabled = false", :order => "position")

    # per scartare le categorie senza nessun prodotto
    @categories = Array.new # or []

    # increase SQL performance!!!
    @all.each do |category|

      category.items.delete_if {|x| x.disabled}

      next if category.items.empty?
      @categories << category
    end

  end
  
  
  def order
    session[:order].save
  end
  

  def summary

    session[:note_to_close] = Array.new
    @empty_note = Array.new

    session[:order] = Order.new( :places => params[:places], :note => params[:order_note] )

    params[:items].each do | i |

      id   = i[0]
      qty  = i[1]["qty"]
      note = i[1]["note"]

      # TODO: migliorare.. magari scriverlo in js -> summary.rjs / order.rjs
      # cancellare le caselle vuote delle note

##      @empty_note << id if note && note.strip.empty?

      if note && note.strip.empty?
        @empty_note << id
      elsif note
        session[:note_to_close] << id
      end

#      session[:note_to_reset] << id if note
#      @empty_note << id if note && note.strip.empty?
      
      next if qty.empty?

      item = Item.find(id)
      
      name = item.name
      price  = item.price * qty.to_i

      session[:order].line_items << LineItem.new( :item => item, :quantity => qty, :price => price, :note => note )

      session[:order].price += price

    end

    # non posso usare session[:order] perchè non saprebbe riconoscere una nota vuota aperta
#    session[:close_order_note] = params[:order_note].nil? || params[:order_note].strip.empty? ? true : nil
    session[:close_order_note] = params[:order_note] ? true : nil

  end


  # TODO: trovare un modo migliore per selezionare un determinato line_item
  #       o almeno ottimizzarlo!

  def add_item_note
    session[:order].line_items.each_with_index do |i, index|
      @i = i if i.item_id == params[:id].to_i
    end
  end


  def update_item_qty
    qty = params[:item_qty].to_i
    session[:order].line_items.each_with_index do |i, index|
      if i.item_id == params[:id].to_i && qty >= 1 && qty <= 99
        i.quantity = qty
        session[:order].price -= i.price
        i.price = qty * i.item.price
        session[:order].price += qty * i.item.price
      end
    end
    refresh
  end

  def update_item_note
    session[:order].line_items.each_with_index do |i, index|
      if i.item_id == params[:id].to_i && !params[:item_note].empty?
        i.note = params[:item_note]
      end
    end
    refresh
  end


  def more_item
    session[:order].line_items.each_with_index do |i, index|
      if i.item_id == params[:id].to_i && i.quantity < 99
        i.quantity += 1
        i.price += i.item.price
        session[:order].price += i.item.price
      end
    end
    refresh
  end
  
  def less_item
    session[:order].line_items.each_with_index do |i, index|
      if i.item_id == params[:id].to_i
        i.quantity -= 1
        i.price -= i.item.price
        session[:order].price -= i.item.price
        session[:order].line_items.delete_at(index) if i.quantity <= 0
      end
    end
    refresh
  end


  def destroy_item
    session[:order].line_items.each_with_index do |i, index|
      if i.item_id == params[:id].to_i
        session[:order].price -= i.price
        session[:order].line_items.delete_at(index)
      end
    end
    refresh
  end
  
  
  def destroy_item_note
    session[:order].line_items.each_with_index do |i, index|
      i.note = nil if i.item_id == params[:id].to_i
    end
    refresh
  end
 
  private
  def refresh
    render :partial => "refresh"
  end

end